summaryrefslogtreecommitdiffstats
path: root/korn/maildlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/maildlg.h')
-rw-r--r--korn/maildlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/korn/maildlg.h b/korn/maildlg.h
index 68f8f30e..81917bb4 100644
--- a/korn/maildlg.h
+++ b/korn/maildlg.h
@@ -46,9 +46,9 @@ class KornMailDlg : public KDialogBase
public:
/**
* KornMailDlg Constructor
* @param tqparent tqparent widget
*/
- KornMailDlg( TQWidget *tqparent=0 );
+ KornMailDlg( TQWidget *parent=0 );
/**
* Set the mail details to show. The mails body is transfered to the edit control
@@ -46,9 +46,9 @@ class KornMailDlg : public KDialogBase
/**
* KornMailDlg Constructor
- * @param tqparent tqparent widget
+ * @param parent parent widget
*/